# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class DatabaseMigrationClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.database_migration.DatabaseMigrationClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new DatabaseMigrationClientCompositeOperations object

        :param DatabaseMigrationClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def abort_job_and_wait_for_state(self, job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.abort_job` and waits for the :py:class:`~oci.database_migration.models.Job` acted upon
        to enter the given state(s).

        :param str job_id: (required)
            The OCID of the job

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.Job.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.abort_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.abort_job(job_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_job(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def clone_migration_and_wait_for_state(self, migration_id, clone_migration_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.clone_migration` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str migration_id: (required)
            The OCID of the migration

        :param oci.database_migration.models.CloneMigrationDetails clone_migration_details: (required)
            Clone Migration properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.clone_migration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.clone_migration(migration_id, clone_migration_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_connection_and_wait_for_state(self, create_connection_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.create_connection` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param oci.database_migration.models.CreateConnectionDetails create_connection_details: (required)
            Database Connection properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.create_connection`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_connection(create_connection_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_migration_and_wait_for_state(self, create_migration_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.create_migration` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param oci.database_migration.models.CreateMigrationDetails create_migration_details: (required)
            Migration properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.create_migration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_migration(create_migration_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_agent_and_wait_for_state(self, agent_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_agent` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str agent_id: (required)
            The OCID of the agent

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_agent`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_agent(agent_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_connection_and_wait_for_state(self, connection_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_connection` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str connection_id: (required)
            The OCID of the database connection

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_connection`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_connection(connection_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_job_and_wait_for_state(self, job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_job` and waits for the :py:class:`~oci.database_migration.models.Job` acted upon
        to enter the given state(s).

        :param str job_id: (required)
            The OCID of the job

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.Job.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_job(job_id)
        operation_result = None
        try:
            operation_result = self.client.delete_job(job_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_migration_and_wait_for_state(self, migration_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_migration` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str migration_id: (required)
            The OCID of the migration

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.delete_migration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_migration(migration_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def evaluate_migration_and_wait_for_state(self, migration_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.evaluate_migration` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str migration_id: (required)
            The OCID of the migration

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.evaluate_migration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.evaluate_migration(migration_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def resume_job_and_wait_for_state(self, job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.resume_job` and waits for the :py:class:`~oci.database_migration.models.Job` acted upon
        to enter the given state(s).

        :param str job_id: (required)
            The OCID of the job

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.Job.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.resume_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.resume_job(job_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_job(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def start_migration_and_wait_for_state(self, migration_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.start_migration` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str migration_id: (required)
            The OCID of the migration

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.start_migration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.start_migration(migration_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_agent_and_wait_for_state(self, agent_id, update_agent_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.update_agent` and waits for the :py:class:`~oci.database_migration.models.Agent` acted upon
        to enter the given state(s).

        :param str agent_id: (required)
            The OCID of the agent

        :param oci.database_migration.models.UpdateAgentDetails update_agent_details: (required)
            Update ODMS Agent properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.Agent.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.update_agent`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_agent(agent_id, update_agent_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_agent(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_connection_and_wait_for_state(self, connection_id, update_connection_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.update_connection` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str connection_id: (required)
            The OCID of the database connection

        :param oci.database_migration.models.UpdateConnectionDetails update_connection_details: (required)
            Database Connection properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.update_connection`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_connection(connection_id, update_connection_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_job_and_wait_for_state(self, job_id, update_job_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.update_job` and waits for the :py:class:`~oci.database_migration.models.Job` acted upon
        to enter the given state(s).

        :param str job_id: (required)
            The OCID of the job

        :param oci.database_migration.models.UpdateJobDetails update_job_details: (required)
            Migration Job properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.Job.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.update_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_job(job_id, update_job_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_job(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_migration_and_wait_for_state(self, migration_id, update_migration_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.database_migration.DatabaseMigrationClient.update_migration` and waits for the :py:class:`~oci.database_migration.models.WorkRequest`
        to enter the given state(s).

        :param str migration_id: (required)
            The OCID of the migration

        :param oci.database_migration.models.UpdateMigrationDetails update_migration_details: (required)
            Migration properties.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.database_migration.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.database_migration.DatabaseMigrationClient.update_migration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_migration(migration_id, update_migration_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateOceInstanceDetails(object):
    """
    The information to be updated.
    """

    #: A constant which can be used with the instance_license_type property of a UpdateOceInstanceDetails.
    #: This constant has a value of "NEW"
    INSTANCE_LICENSE_TYPE_NEW = "NEW"

    #: A constant which can be used with the instance_license_type property of a UpdateOceInstanceDetails.
    #: This constant has a value of "BYOL"
    INSTANCE_LICENSE_TYPE_BYOL = "BYOL"

    #: A constant which can be used with the instance_license_type property of a UpdateOceInstanceDetails.
    #: This constant has a value of "PREMIUM"
    INSTANCE_LICENSE_TYPE_PREMIUM = "PREMIUM"

    #: A constant which can be used with the instance_license_type property of a UpdateOceInstanceDetails.
    #: This constant has a value of "STARTER"
    INSTANCE_LICENSE_TYPE_STARTER = "STARTER"

    #: A constant which can be used with the instance_usage_type property of a UpdateOceInstanceDetails.
    #: This constant has a value of "PRIMARY"
    INSTANCE_USAGE_TYPE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the instance_usage_type property of a UpdateOceInstanceDetails.
    #: This constant has a value of "NONPRIMARY"
    INSTANCE_USAGE_TYPE_NONPRIMARY = "NONPRIMARY"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateOceInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateOceInstanceDetails.
        :type description: str

        :param waf_primary_domain:
            The value to assign to the waf_primary_domain property of this UpdateOceInstanceDetails.
        :type waf_primary_domain: str

        :param instance_license_type:
            The value to assign to the instance_license_type property of this UpdateOceInstanceDetails.
            Allowed values for this property are: "NEW", "BYOL", "PREMIUM", "STARTER"
        :type instance_license_type: str

        :param instance_usage_type:
            The value to assign to the instance_usage_type property of this UpdateOceInstanceDetails.
            Allowed values for this property are: "PRIMARY", "NONPRIMARY"
        :type instance_usage_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateOceInstanceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateOceInstanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'description': 'str',
            'waf_primary_domain': 'str',
            'instance_license_type': 'str',
            'instance_usage_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'description': 'description',
            'waf_primary_domain': 'wafPrimaryDomain',
            'instance_license_type': 'instanceLicenseType',
            'instance_usage_type': 'instanceUsageType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._description = None
        self._waf_primary_domain = None
        self._instance_license_type = None
        self._instance_usage_type = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def description(self):
        """
        Gets the description of this UpdateOceInstanceDetails.
        OceInstance description


        :return: The description of this UpdateOceInstanceDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateOceInstanceDetails.
        OceInstance description


        :param description: The description of this UpdateOceInstanceDetails.
        :type: str
        """
        self._description = description

    @property
    def waf_primary_domain(self):
        """
        Gets the waf_primary_domain of this UpdateOceInstanceDetails.
        Web Application Firewall(WAF) primary domain


        :return: The waf_primary_domain of this UpdateOceInstanceDetails.
        :rtype: str
        """
        return self._waf_primary_domain

    @waf_primary_domain.setter
    def waf_primary_domain(self, waf_primary_domain):
        """
        Sets the waf_primary_domain of this UpdateOceInstanceDetails.
        Web Application Firewall(WAF) primary domain


        :param waf_primary_domain: The waf_primary_domain of this UpdateOceInstanceDetails.
        :type: str
        """
        self._waf_primary_domain = waf_primary_domain

    @property
    def instance_license_type(self):
        """
        Gets the instance_license_type of this UpdateOceInstanceDetails.
        Flag indicating whether the instance license is new cloud or bring your own license

        Allowed values for this property are: "NEW", "BYOL", "PREMIUM", "STARTER"


        :return: The instance_license_type of this UpdateOceInstanceDetails.
        :rtype: str
        """
        return self._instance_license_type

    @instance_license_type.setter
    def instance_license_type(self, instance_license_type):
        """
        Sets the instance_license_type of this UpdateOceInstanceDetails.
        Flag indicating whether the instance license is new cloud or bring your own license


        :param instance_license_type: The instance_license_type of this UpdateOceInstanceDetails.
        :type: str
        """
        allowed_values = ["NEW", "BYOL", "PREMIUM", "STARTER"]
        if not value_allowed_none_or_none_sentinel(instance_license_type, allowed_values):
            raise ValueError(
                "Invalid value for `instance_license_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._instance_license_type = instance_license_type

    @property
    def instance_usage_type(self):
        """
        Gets the instance_usage_type of this UpdateOceInstanceDetails.
        Instance type based on its usage

        Allowed values for this property are: "PRIMARY", "NONPRIMARY"


        :return: The instance_usage_type of this UpdateOceInstanceDetails.
        :rtype: str
        """
        return self._instance_usage_type

    @instance_usage_type.setter
    def instance_usage_type(self, instance_usage_type):
        """
        Sets the instance_usage_type of this UpdateOceInstanceDetails.
        Instance type based on its usage


        :param instance_usage_type: The instance_usage_type of this UpdateOceInstanceDetails.
        :type: str
        """
        allowed_values = ["PRIMARY", "NONPRIMARY"]
        if not value_allowed_none_or_none_sentinel(instance_usage_type, allowed_values):
            raise ValueError(
                "Invalid value for `instance_usage_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._instance_usage_type = instance_usage_type

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateOceInstanceDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateOceInstanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateOceInstanceDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateOceInstanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateOceInstanceDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateOceInstanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateOceInstanceDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateOceInstanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .compute_instance_group_selector import ComputeInstanceGroupSelector
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeInstanceGroupByIdsSelector(ComputeInstanceGroupSelector):
    """
    Specifies the Compute instance group environment by listing the OCIDs of the compute instances.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeInstanceGroupByIdsSelector object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.ComputeInstanceGroupByIdsSelector.selector_type` attribute
        of this class is ``INSTANCE_IDS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param selector_type:
            The value to assign to the selector_type property of this ComputeInstanceGroupByIdsSelector.
            Allowed values for this property are: "INSTANCE_IDS", "INSTANCE_QUERY"
        :type selector_type: str

        :param compute_instance_ids:
            The value to assign to the compute_instance_ids property of this ComputeInstanceGroupByIdsSelector.
        :type compute_instance_ids: list[str]

        """
        self.swagger_types = {
            'selector_type': 'str',
            'compute_instance_ids': 'list[str]'
        }

        self.attribute_map = {
            'selector_type': 'selectorType',
            'compute_instance_ids': 'computeInstanceIds'
        }

        self._selector_type = None
        self._compute_instance_ids = None
        self._selector_type = 'INSTANCE_IDS'

    @property
    def compute_instance_ids(self):
        """
        **[Required]** Gets the compute_instance_ids of this ComputeInstanceGroupByIdsSelector.
        Compute instance OCID identifiers that are members of this group.


        :return: The compute_instance_ids of this ComputeInstanceGroupByIdsSelector.
        :rtype: list[str]
        """
        return self._compute_instance_ids

    @compute_instance_ids.setter
    def compute_instance_ids(self, compute_instance_ids):
        """
        Sets the compute_instance_ids of this ComputeInstanceGroupByIdsSelector.
        Compute instance OCID identifiers that are members of this group.


        :param compute_instance_ids: The compute_instance_ids of this ComputeInstanceGroupByIdsSelector.
        :type: list[str]
        """
        self._compute_instance_ids = compute_instance_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_details import TargetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StreamingTargetDetails(TargetDetails):
    """
    The stream used for the Streaming target.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StreamingTargetDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.sch.models.StreamingTargetDetails.kind` attribute
        of this class is ``streaming`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this StreamingTargetDetails.
            Allowed values for this property are: "functions", "loggingAnalytics", "monitoring", "notifications", "objectStorage", "streaming"
        :type kind: str

        :param stream_id:
            The value to assign to the stream_id property of this StreamingTargetDetails.
        :type stream_id: str

        """
        self.swagger_types = {
            'kind': 'str',
            'stream_id': 'str'
        }

        self.attribute_map = {
            'kind': 'kind',
            'stream_id': 'streamId'
        }

        self._kind = None
        self._stream_id = None
        self._kind = 'streaming'

    @property
    def stream_id(self):
        """
        **[Required]** Gets the stream_id of this StreamingTargetDetails.
        The `OCID`__ of the stream.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stream_id of this StreamingTargetDetails.
        :rtype: str
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        """
        Sets the stream_id of this StreamingTargetDetails.
        The `OCID`__ of the stream.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stream_id: The stream_id of this StreamingTargetDetails.
        :type: str
        """
        self._stream_id = stream_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class BlockchainPlatformClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.blockchain.BlockchainPlatformClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new BlockchainPlatformClientCompositeOperations object

        :param BlockchainPlatformClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_blockchain_platform_compartment_and_wait_for_state(self, blockchain_platform_id, change_blockchain_platform_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.change_blockchain_platform_compartment` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param oci.blockchain.models.ChangeBlockchainPlatformCompartmentDetails change_blockchain_platform_compartment_details: (required)
            Input payload to move the resource to a different compartment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.change_blockchain_platform_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_blockchain_platform_compartment(blockchain_platform_id, change_blockchain_platform_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_blockchain_platform_and_wait_for_state(self, create_blockchain_platform_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.create_blockchain_platform` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param oci.blockchain.models.CreateBlockchainPlatformDetails create_blockchain_platform_details: (required)
            Details for the new service.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.create_blockchain_platform`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_blockchain_platform(create_blockchain_platform_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_osn_and_wait_for_state(self, blockchain_platform_id, create_osn_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.create_osn` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param oci.blockchain.models.CreateOsnDetails create_osn_details: (required)
            Input payload to create blockchain platform OSN. The payload cannot be empty.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.create_osn`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_osn(blockchain_platform_id, create_osn_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_peer_and_wait_for_state(self, blockchain_platform_id, create_peer_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.create_peer` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param oci.blockchain.models.CreatePeerDetails create_peer_details: (required)
            Input payload to create a blockchain platform peer. The payload cannot be empty.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.create_peer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_peer(blockchain_platform_id, create_peer_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_blockchain_platform_and_wait_for_state(self, blockchain_platform_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_blockchain_platform` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_blockchain_platform`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_blockchain_platform(blockchain_platform_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_osn_and_wait_for_state(self, blockchain_platform_id, osn_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_osn` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param str osn_id: (required)
            OSN identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_osn`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_osn(blockchain_platform_id, osn_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_peer_and_wait_for_state(self, blockchain_platform_id, peer_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_peer` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param str peer_id: (required)
            Peer identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_peer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_peer(blockchain_platform_id, peer_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_work_request_and_wait_for_state(self, work_request_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_work_request` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str work_request_id: (required)
            The ID of the asynchronous request.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.delete_work_request`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_work_request(work_request_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def scale_blockchain_platform_and_wait_for_state(self, blockchain_platform_id, scale_blockchain_platform_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.scale_blockchain_platform` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param oci.blockchain.models.ScaleBlockchainPlatformDetails scale_blockchain_platform_details: (required)
            Input payload to scaleout blockchain platform. The payload cannot be empty.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.scale_blockchain_platform`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.scale_blockchain_platform(blockchain_platform_id, scale_blockchain_platform_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def start_blockchain_platform_and_wait_for_state(self, blockchain_platform_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.start_blockchain_platform` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.start_blockchain_platform`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.start_blockchain_platform(blockchain_platform_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def stop_blockchain_platform_and_wait_for_state(self, blockchain_platform_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.stop_blockchain_platform` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.stop_blockchain_platform`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.stop_blockchain_platform(blockchain_platform_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_blockchain_platform_and_wait_for_state(self, update_blockchain_platform_details, blockchain_platform_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.update_blockchain_platform` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param oci.blockchain.models.UpdateBlockchainPlatformDetails update_blockchain_platform_details: (required)
            The Blockchain Platform fields to update. Fields that are not provided will not be updated.

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.update_blockchain_platform`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_blockchain_platform(update_blockchain_platform_details, blockchain_platform_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_osn_and_wait_for_state(self, blockchain_platform_id, osn_id, update_osn_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.update_osn` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param str osn_id: (required)
            OSN identifier.

        :param oci.blockchain.models.UpdateOsnDetails update_osn_details: (required)
            Input payload to update a blockchain platform OSN. The payload cannot be empty.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.update_osn`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_osn(blockchain_platform_id, osn_id, update_osn_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_peer_and_wait_for_state(self, blockchain_platform_id, peer_id, update_peer_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.blockchain.BlockchainPlatformClient.update_peer` and waits for the :py:class:`~oci.blockchain.models.WorkRequest`
        to enter the given state(s).

        :param str blockchain_platform_id: (required)
            Unique service identifier.

        :param str peer_id: (required)
            Peer identifier.

        :param oci.blockchain.models.UpdatePeerDetails update_peer_details: (required)
            Input payload to update a blockchain platform peer. The payload cannot be empty.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.blockchain.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.blockchain.BlockchainPlatformClient.update_peer`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_peer(blockchain_platform_id, peer_id, update_peer_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDataTransferMediumDetails(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Data Transfer Medium details for the Migration.
    Only one type of data transfer medium can be specified and will replace the stored Data Transfer Medium details.
    If an empty object is specified, the stored Data Transfer Medium details will be removed.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDataTransferMediumDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_link_details:
            The value to assign to the database_link_details property of this UpdateDataTransferMediumDetails.
        :type database_link_details: oci.database_migration.models.UpdateDatabaseLinkDetails

        :param object_storage_details:
            The value to assign to the object_storage_details property of this UpdateDataTransferMediumDetails.
        :type object_storage_details: oci.database_migration.models.UpdateObjectStoreBucket

        """
        self.swagger_types = {
            'database_link_details': 'UpdateDatabaseLinkDetails',
            'object_storage_details': 'UpdateObjectStoreBucket'
        }

        self.attribute_map = {
            'database_link_details': 'databaseLinkDetails',
            'object_storage_details': 'objectStorageDetails'
        }

        self._database_link_details = None
        self._object_storage_details = None

    @property
    def database_link_details(self):
        """
        Gets the database_link_details of this UpdateDataTransferMediumDetails.

        :return: The database_link_details of this UpdateDataTransferMediumDetails.
        :rtype: oci.database_migration.models.UpdateDatabaseLinkDetails
        """
        return self._database_link_details

    @database_link_details.setter
    def database_link_details(self, database_link_details):
        """
        Sets the database_link_details of this UpdateDataTransferMediumDetails.

        :param database_link_details: The database_link_details of this UpdateDataTransferMediumDetails.
        :type: oci.database_migration.models.UpdateDatabaseLinkDetails
        """
        self._database_link_details = database_link_details

    @property
    def object_storage_details(self):
        """
        Gets the object_storage_details of this UpdateDataTransferMediumDetails.

        :return: The object_storage_details of this UpdateDataTransferMediumDetails.
        :rtype: oci.database_migration.models.UpdateObjectStoreBucket
        """
        return self._object_storage_details

    @object_storage_details.setter
    def object_storage_details(self, object_storage_details):
        """
        Sets the object_storage_details of this UpdateDataTransferMediumDetails.

        :param object_storage_details: The object_storage_details of this UpdateDataTransferMediumDetails.
        :type: oci.database_migration.models.UpdateObjectStoreBucket
        """
        self._object_storage_details = object_storage_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Column(object):
    """
    A column of a table.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Column object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Column.
        :type name: str

        :param type:
            The value to assign to the type property of this Column.
        :type type: str

        :param is_nullable:
            The value to assign to the is_nullable property of this Column.
        :type is_nullable: bool

        :param default_value:
            The value to assign to the default_value property of this Column.
        :type default_value: str

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'is_nullable': 'bool',
            'default_value': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'is_nullable': 'isNullable',
            'default_value': 'defaultValue'
        }

        self._name = None
        self._type = None
        self._is_nullable = None
        self._default_value = None

    @property
    def name(self):
        """
        Gets the name of this Column.
        The column name.


        :return: The name of this Column.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Column.
        The column name.


        :param name: The name of this Column.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this Column.
        The column type.


        :return: The type of this Column.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Column.
        The column type.


        :param type: The type of this Column.
        :type: str
        """
        self._type = type

    @property
    def is_nullable(self):
        """
        Gets the is_nullable of this Column.
        The column nullable flag.


        :return: The is_nullable of this Column.
        :rtype: bool
        """
        return self._is_nullable

    @is_nullable.setter
    def is_nullable(self, is_nullable):
        """
        Sets the is_nullable of this Column.
        The column nullable flag.


        :param is_nullable: The is_nullable of this Column.
        :type: bool
        """
        self._is_nullable = is_nullable

    @property
    def default_value(self):
        """
        Gets the default_value of this Column.
        The column default value.


        :return: The default_value of this Column.
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this Column.
        The column default value.


        :param default_value: The default_value of this Column.
        :type: str
        """
        self._default_value = default_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConfigParameterDefinition(object):
    """
    The configurable properties of an object type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConfigParameterDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parameter_type:
            The value to assign to the parameter_type property of this ConfigParameterDefinition.
        :type parameter_type: oci.data_integration.models.BaseType

        :param parameter_name:
            The value to assign to the parameter_name property of this ConfigParameterDefinition.
        :type parameter_name: str

        :param description:
            The value to assign to the description property of this ConfigParameterDefinition.
        :type description: str

        :param default_value:
            The value to assign to the default_value property of this ConfigParameterDefinition.
        :type default_value: object

        :param class_field_name:
            The value to assign to the class_field_name property of this ConfigParameterDefinition.
        :type class_field_name: str

        :param is_static:
            The value to assign to the is_static property of this ConfigParameterDefinition.
        :type is_static: bool

        :param is_class_field_value:
            The value to assign to the is_class_field_value property of this ConfigParameterDefinition.
        :type is_class_field_value: bool

        """
        self.swagger_types = {
            'parameter_type': 'BaseType',
            'parameter_name': 'str',
            'description': 'str',
            'default_value': 'object',
            'class_field_name': 'str',
            'is_static': 'bool',
            'is_class_field_value': 'bool'
        }

        self.attribute_map = {
            'parameter_type': 'parameterType',
            'parameter_name': 'parameterName',
            'description': 'description',
            'default_value': 'defaultValue',
            'class_field_name': 'classFieldName',
            'is_static': 'isStatic',
            'is_class_field_value': 'isClassFieldValue'
        }

        self._parameter_type = None
        self._parameter_name = None
        self._description = None
        self._default_value = None
        self._class_field_name = None
        self._is_static = None
        self._is_class_field_value = None

    @property
    def parameter_type(self):
        """
        Gets the parameter_type of this ConfigParameterDefinition.

        :return: The parameter_type of this ConfigParameterDefinition.
        :rtype: oci.data_integration.models.BaseType
        """
        return self._parameter_type

    @parameter_type.setter
    def parameter_type(self, parameter_type):
        """
        Sets the parameter_type of this ConfigParameterDefinition.

        :param parameter_type: The parameter_type of this ConfigParameterDefinition.
        :type: oci.data_integration.models.BaseType
        """
        self._parameter_type = parameter_type

    @property
    def parameter_name(self):
        """
        Gets the parameter_name of this ConfigParameterDefinition.
        This object represents the configurable properties for an object type.


        :return: The parameter_name of this ConfigParameterDefinition.
        :rtype: str
        """
        return self._parameter_name

    @parameter_name.setter
    def parameter_name(self, parameter_name):
        """
        Sets the parameter_name of this ConfigParameterDefinition.
        This object represents the configurable properties for an object type.


        :param parameter_name: The parameter_name of this ConfigParameterDefinition.
        :type: str
        """
        self._parameter_name = parameter_name

    @property
    def description(self):
        """
        Gets the description of this ConfigParameterDefinition.
        A user defined description for the object.


        :return: The description of this ConfigParameterDefinition.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConfigParameterDefinition.
        A user defined description for the object.


        :param description: The description of this ConfigParameterDefinition.
        :type: str
        """
        self._description = description

    @property
    def default_value(self):
        """
        Gets the default_value of this ConfigParameterDefinition.
        The default value for the parameter.


        :return: The default_value of this ConfigParameterDefinition.
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this ConfigParameterDefinition.
        The default value for the parameter.


        :param default_value: The default_value of this ConfigParameterDefinition.
        :type: object
        """
        self._default_value = default_value

    @property
    def class_field_name(self):
        """
        Gets the class_field_name of this ConfigParameterDefinition.
        The parameter class field name.


        :return: The class_field_name of this ConfigParameterDefinition.
        :rtype: str
        """
        return self._class_field_name

    @class_field_name.setter
    def class_field_name(self, class_field_name):
        """
        Sets the class_field_name of this ConfigParameterDefinition.
        The parameter class field name.


        :param class_field_name: The class_field_name of this ConfigParameterDefinition.
        :type: str
        """
        self._class_field_name = class_field_name

    @property
    def is_static(self):
        """
        Gets the is_static of this ConfigParameterDefinition.
        Specifies whether the parameter is static or not.


        :return: The is_static of this ConfigParameterDefinition.
        :rtype: bool
        """
        return self._is_static

    @is_static.setter
    def is_static(self, is_static):
        """
        Sets the is_static of this ConfigParameterDefinition.
        Specifies whether the parameter is static or not.


        :param is_static: The is_static of this ConfigParameterDefinition.
        :type: bool
        """
        self._is_static = is_static

    @property
    def is_class_field_value(self):
        """
        Gets the is_class_field_value of this ConfigParameterDefinition.
        Specifies whether the parameter is a class field or not.


        :return: The is_class_field_value of this ConfigParameterDefinition.
        :rtype: bool
        """
        return self._is_class_field_value

    @is_class_field_value.setter
    def is_class_field_value(self, is_class_field_value):
        """
        Sets the is_class_field_value of this ConfigParameterDefinition.
        Specifies whether the parameter is a class field or not.


        :param is_class_field_value: The is_class_field_value of this ConfigParameterDefinition.
        :type: bool
        """
        self._is_class_field_value = is_class_field_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecretContentDetails(object):
    """
    The content of the secret and metadata to help identify it.
    """

    #: A constant which can be used with the content_type property of a SecretContentDetails.
    #: This constant has a value of "BASE64"
    CONTENT_TYPE_BASE64 = "BASE64"

    #: A constant which can be used with the stage property of a SecretContentDetails.
    #: This constant has a value of "CURRENT"
    STAGE_CURRENT = "CURRENT"

    #: A constant which can be used with the stage property of a SecretContentDetails.
    #: This constant has a value of "PENDING"
    STAGE_PENDING = "PENDING"

    def __init__(self, **kwargs):
        """
        Initializes a new SecretContentDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.vault.models.Base64SecretContentDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param content_type:
            The value to assign to the content_type property of this SecretContentDetails.
            Allowed values for this property are: "BASE64"
        :type content_type: str

        :param name:
            The value to assign to the name property of this SecretContentDetails.
        :type name: str

        :param stage:
            The value to assign to the stage property of this SecretContentDetails.
            Allowed values for this property are: "CURRENT", "PENDING"
        :type stage: str

        """
        self.swagger_types = {
            'content_type': 'str',
            'name': 'str',
            'stage': 'str'
        }

        self.attribute_map = {
            'content_type': 'contentType',
            'name': 'name',
            'stage': 'stage'
        }

        self._content_type = None
        self._name = None
        self._stage = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['contentType']

        if type == 'BASE64':
            return 'Base64SecretContentDetails'
        else:
            return 'SecretContentDetails'

    @property
    def content_type(self):
        """
        **[Required]** Gets the content_type of this SecretContentDetails.
        The base64-encoded content of the secret.

        Allowed values for this property are: "BASE64"


        :return: The content_type of this SecretContentDetails.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this SecretContentDetails.
        The base64-encoded content of the secret.


        :param content_type: The content_type of this SecretContentDetails.
        :type: str
        """
        allowed_values = ["BASE64"]
        if not value_allowed_none_or_none_sentinel(content_type, allowed_values):
            raise ValueError(
                "Invalid value for `content_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._content_type = content_type

    @property
    def name(self):
        """
        Gets the name of this SecretContentDetails.
        Names should be unique within a secret. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :return: The name of this SecretContentDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SecretContentDetails.
        Names should be unique within a secret. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :param name: The name of this SecretContentDetails.
        :type: str
        """
        self._name = name

    @property
    def stage(self):
        """
        Gets the stage of this SecretContentDetails.
        The rotation state of the secret content. The default is `CURRENT`, meaning that the secret is currently in use. A secret version
        that you mark as `PENDING` is staged and available for use, but you don't yet want to rotate it into current, active use. For example,
        you might create or update a secret and mark its rotation state as `PENDING` if you haven't yet updated the secret on the target system.
        When creating a secret, only the value `CURRENT` is applicable, although the value `LATEST` is also automatically applied. When updating
        a secret, you can specify a version's rotation state as either `CURRENT` or `PENDING`.

        Allowed values for this property are: "CURRENT", "PENDING"


        :return: The stage of this SecretContentDetails.
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """
        Sets the stage of this SecretContentDetails.
        The rotation state of the secret content. The default is `CURRENT`, meaning that the secret is currently in use. A secret version
        that you mark as `PENDING` is staged and available for use, but you don't yet want to rotate it into current, active use. For example,
        you might create or update a secret and mark its rotation state as `PENDING` if you haven't yet updated the secret on the target system.
        When creating a secret, only the value `CURRENT` is applicable, although the value `LATEST` is also automatically applied. When updating
        a secret, you can specify a version's rotation state as either `CURRENT` or `PENDING`.


        :param stage: The stage of this SecretContentDetails.
        :type: str
        """
        allowed_values = ["CURRENT", "PENDING"]
        if not value_allowed_none_or_none_sentinel(stage, allowed_values):
            raise ValueError(
                "Invalid value for `stage`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._stage = stage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagementAgentSummary(object):
    """
    The summary of the Management Agent inventory including the associated plugins.
    """

    #: A constant which can be used with the platform_type property of a ManagementAgentSummary.
    #: This constant has a value of "LINUX"
    PLATFORM_TYPE_LINUX = "LINUX"

    #: A constant which can be used with the platform_type property of a ManagementAgentSummary.
    #: This constant has a value of "WINDOWS"
    PLATFORM_TYPE_WINDOWS = "WINDOWS"

    #: A constant which can be used with the availability_status property of a ManagementAgentSummary.
    #: This constant has a value of "ACTIVE"
    AVAILABILITY_STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the availability_status property of a ManagementAgentSummary.
    #: This constant has a value of "SILENT"
    AVAILABILITY_STATUS_SILENT = "SILENT"

    #: A constant which can be used with the availability_status property of a ManagementAgentSummary.
    #: This constant has a value of "NOT_AVAILABLE"
    AVAILABILITY_STATUS_NOT_AVAILABLE = "NOT_AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ManagementAgentSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagementAgentSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ManagementAgentSummary.
        :type id: str

        :param install_key_id:
            The value to assign to the install_key_id property of this ManagementAgentSummary.
        :type install_key_id: str

        :param display_name:
            The value to assign to the display_name property of this ManagementAgentSummary.
        :type display_name: str

        :param platform_type:
            The value to assign to the platform_type property of this ManagementAgentSummary.
            Allowed values for this property are: "LINUX", "WINDOWS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type platform_type: str

        :param platform_name:
            The value to assign to the platform_name property of this ManagementAgentSummary.
        :type platform_name: str

        :param platform_version:
            The value to assign to the platform_version property of this ManagementAgentSummary.
        :type platform_version: str

        :param version:
            The value to assign to the version property of this ManagementAgentSummary.
        :type version: str

        :param is_agent_auto_upgradable:
            The value to assign to the is_agent_auto_upgradable property of this ManagementAgentSummary.
        :type is_agent_auto_upgradable: bool

        :param time_created:
            The value to assign to the time_created property of this ManagementAgentSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ManagementAgentSummary.
        :type time_updated: datetime

        :param host:
            The value to assign to the host property of this ManagementAgentSummary.
        :type host: str

        :param host_id:
            The value to assign to the host_id property of this ManagementAgentSummary.
        :type host_id: str

        :param plugin_list:
            The value to assign to the plugin_list property of this ManagementAgentSummary.
        :type plugin_list: list[oci.management_agent.models.ManagementAgentPluginDetails]

        :param compartment_id:
            The value to assign to the compartment_id property of this ManagementAgentSummary.
        :type compartment_id: str

        :param time_last_heartbeat:
            The value to assign to the time_last_heartbeat property of this ManagementAgentSummary.
        :type time_last_heartbeat: datetime

        :param availability_status:
            The value to assign to the availability_status property of this ManagementAgentSummary.
            Allowed values for this property are: "ACTIVE", "SILENT", "NOT_AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type availability_status: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ManagementAgentSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ManagementAgentSummary.
        :type lifecycle_details: str

        :param is_customer_deployed:
            The value to assign to the is_customer_deployed property of this ManagementAgentSummary.
        :type is_customer_deployed: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ManagementAgentSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ManagementAgentSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'install_key_id': 'str',
            'display_name': 'str',
            'platform_type': 'str',
            'platform_name': 'str',
            'platform_version': 'str',
            'version': 'str',
            'is_agent_auto_upgradable': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'host': 'str',
            'host_id': 'str',
            'plugin_list': 'list[ManagementAgentPluginDetails]',
            'compartment_id': 'str',
            'time_last_heartbeat': 'datetime',
            'availability_status': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'is_customer_deployed': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'install_key_id': 'installKeyId',
            'display_name': 'displayName',
            'platform_type': 'platformType',
            'platform_name': 'platformName',
            'platform_version': 'platformVersion',
            'version': 'version',
            'is_agent_auto_upgradable': 'isAgentAutoUpgradable',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'host': 'host',
            'host_id': 'hostId',
            'plugin_list': 'pluginList',
            'compartment_id': 'compartmentId',
            'time_last_heartbeat': 'timeLastHeartbeat',
            'availability_status': 'availabilityStatus',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'is_customer_deployed': 'isCustomerDeployed',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._install_key_id = None
        self._display_name = None
        self._platform_type = None
        self._platform_name = None
        self._platform_version = None
        self._version = None
        self._is_agent_auto_upgradable = None
        self._time_created = None
        self._time_updated = None
        self._host = None
        self._host_id = None
        self._plugin_list = None
        self._compartment_id = None
        self._time_last_heartbeat = None
        self._availability_status = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._is_customer_deployed = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ManagementAgentSummary.
        agent identifier


        :return: The id of this ManagementAgentSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagementAgentSummary.
        agent identifier


        :param id: The id of this ManagementAgentSummary.
        :type: str
        """
        self._id = id

    @property
    def install_key_id(self):
        """
        Gets the install_key_id of this ManagementAgentSummary.
        agent install key identifier


        :return: The install_key_id of this ManagementAgentSummary.
        :rtype: str
        """
        return self._install_key_id

    @install_key_id.setter
    def install_key_id(self, install_key_id):
        """
        Sets the install_key_id of this ManagementAgentSummary.
        agent install key identifier


        :param install_key_id: The install_key_id of this ManagementAgentSummary.
        :type: str
        """
        self._install_key_id = install_key_id

    @property
    def display_name(self):
        """
        Gets the display_name of this ManagementAgentSummary.
        Management Agent Name


        :return: The display_name of this ManagementAgentSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagementAgentSummary.
        Management Agent Name


        :param display_name: The display_name of this ManagementAgentSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def platform_type(self):
        """
        Gets the platform_type of this ManagementAgentSummary.
        Platform Type

        Allowed values for this property are: "LINUX", "WINDOWS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The platform_type of this ManagementAgentSummary.
        :rtype: str
        """
        return self._platform_type

    @platform_type.setter
    def platform_type(self, platform_type):
        """
        Sets the platform_type of this ManagementAgentSummary.
        Platform Type


        :param platform_type: The platform_type of this ManagementAgentSummary.
        :type: str
        """
        allowed_values = ["LINUX", "WINDOWS"]
        if not value_allowed_none_or_none_sentinel(platform_type, allowed_values):
            platform_type = 'UNKNOWN_ENUM_VALUE'
        self._platform_type = platform_type

    @property
    def platform_name(self):
        """
        Gets the platform_name of this ManagementAgentSummary.
        Platform Name


        :return: The platform_name of this ManagementAgentSummary.
        :rtype: str
        """
        return self._platform_name

    @platform_name.setter
    def platform_name(self, platform_name):
        """
        Sets the platform_name of this ManagementAgentSummary.
        Platform Name


        :param platform_name: The platform_name of this ManagementAgentSummary.
        :type: str
        """
        self._platform_name = platform_name

    @property
    def platform_version(self):
        """
        Gets the platform_version of this ManagementAgentSummary.
        Platform Version


        :return: The platform_version of this ManagementAgentSummary.
        :rtype: str
        """
        return self._platform_version

    @platform_version.setter
    def platform_version(self, platform_version):
        """
        Sets the platform_version of this ManagementAgentSummary.
        Platform Version


        :param platform_version: The platform_version of this ManagementAgentSummary.
        :type: str
        """
        self._platform_version = platform_version

    @property
    def version(self):
        """
        **[Required]** Gets the version of this ManagementAgentSummary.
        Management Agent Version


        :return: The version of this ManagementAgentSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ManagementAgentSummary.
        Management Agent Version


        :param version: The version of this ManagementAgentSummary.
        :type: str
        """
        self._version = version

    @property
    def is_agent_auto_upgradable(self):
        """
        Gets the is_agent_auto_upgradable of this ManagementAgentSummary.
        true if the agent can be upgraded automatically; false if it must be upgraded manually.


        :return: The is_agent_auto_upgradable of this ManagementAgentSummary.
        :rtype: bool
        """
        return self._is_agent_auto_upgradable

    @is_agent_auto_upgradable.setter
    def is_agent_auto_upgradable(self, is_agent_auto_upgradable):
        """
        Sets the is_agent_auto_upgradable of this ManagementAgentSummary.
        true if the agent can be upgraded automatically; false if it must be upgraded manually.


        :param is_agent_auto_upgradable: The is_agent_auto_upgradable of this ManagementAgentSummary.
        :type: bool
        """
        self._is_agent_auto_upgradable = is_agent_auto_upgradable

    @property
    def time_created(self):
        """
        Gets the time_created of this ManagementAgentSummary.
        The time the Management Agent was created. An RFC3339 formatted datetime string


        :return: The time_created of this ManagementAgentSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ManagementAgentSummary.
        The time the Management Agent was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this ManagementAgentSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ManagementAgentSummary.
        The time the Management Agent was last updated. An RFC3339 formatted datetime string


        :return: The time_updated of this ManagementAgentSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ManagementAgentSummary.
        The time the Management Agent was last updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this ManagementAgentSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def host(self):
        """
        Gets the host of this ManagementAgentSummary.
        Management Agent host machine name


        :return: The host of this ManagementAgentSummary.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this ManagementAgentSummary.
        Management Agent host machine name


        :param host: The host of this ManagementAgentSummary.
        :type: str
        """
        self._host = host

    @property
    def host_id(self):
        """
        Gets the host_id of this ManagementAgentSummary.
        Host resource ocid


        :return: The host_id of this ManagementAgentSummary.
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        """
        Sets the host_id of this ManagementAgentSummary.
        Host resource ocid


        :param host_id: The host_id of this ManagementAgentSummary.
        :type: str
        """
        self._host_id = host_id

    @property
    def plugin_list(self):
        """
        Gets the plugin_list of this ManagementAgentSummary.
        list of managementAgentPlugins associated with the agent


        :return: The plugin_list of this ManagementAgentSummary.
        :rtype: list[oci.management_agent.models.ManagementAgentPluginDetails]
        """
        return self._plugin_list

    @plugin_list.setter
    def plugin_list(self, plugin_list):
        """
        Sets the plugin_list of this ManagementAgentSummary.
        list of managementAgentPlugins associated with the agent


        :param plugin_list: The plugin_list of this ManagementAgentSummary.
        :type: list[oci.management_agent.models.ManagementAgentPluginDetails]
        """
        self._plugin_list = plugin_list

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ManagementAgentSummary.
        Compartment Identifier


        :return: The compartment_id of this ManagementAgentSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ManagementAgentSummary.
        Compartment Identifier


        :param compartment_id: The compartment_id of this ManagementAgentSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_last_heartbeat(self):
        """
        Gets the time_last_heartbeat of this ManagementAgentSummary.
        The time the Management Agent has last recorded its heartbeat. An RFC3339 formatted datetime string


        :return: The time_last_heartbeat of this ManagementAgentSummary.
        :rtype: datetime
        """
        return self._time_last_heartbeat

    @time_last_heartbeat.setter
    def time_last_heartbeat(self, time_last_heartbeat):
        """
        Sets the time_last_heartbeat of this ManagementAgentSummary.
        The time the Management Agent has last recorded its heartbeat. An RFC3339 formatted datetime string


        :param time_last_heartbeat: The time_last_heartbeat of this ManagementAgentSummary.
        :type: datetime
        """
        self._time_last_heartbeat = time_last_heartbeat

    @property
    def availability_status(self):
        """
        Gets the availability_status of this ManagementAgentSummary.
        The current availability status of managementAgent

        Allowed values for this property are: "ACTIVE", "SILENT", "NOT_AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The availability_status of this ManagementAgentSummary.
        :rtype: str
        """
        return self._availability_status

    @availability_status.setter
    def availability_status(self, availability_status):
        """
        Sets the availability_status of this ManagementAgentSummary.
        The current availability status of managementAgent


        :param availability_status: The availability_status of this ManagementAgentSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "SILENT", "NOT_AVAILABLE"]
        if not value_allowed_none_or_none_sentinel(availability_status, allowed_values):
            availability_status = 'UNKNOWN_ENUM_VALUE'
        self._availability_status = availability_status

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this ManagementAgentSummary.
        The current state of managementAgent

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ManagementAgentSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ManagementAgentSummary.
        The current state of managementAgent


        :param lifecycle_state: The lifecycle_state of this ManagementAgentSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "TERMINATED", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ManagementAgentSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this ManagementAgentSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ManagementAgentSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this ManagementAgentSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def is_customer_deployed(self):
        """
        Gets the is_customer_deployed of this ManagementAgentSummary.
        true, if the agent image is manually downloaded and installed. false, if the agent is deployed as a plugin in Oracle Cloud Agent.


        :return: The is_customer_deployed of this ManagementAgentSummary.
        :rtype: bool
        """
        return self._is_customer_deployed

    @is_customer_deployed.setter
    def is_customer_deployed(self, is_customer_deployed):
        """
        Sets the is_customer_deployed of this ManagementAgentSummary.
        true, if the agent image is manually downloaded and installed. false, if the agent is deployed as a plugin in Oracle Cloud Agent.


        :param is_customer_deployed: The is_customer_deployed of this ManagementAgentSummary.
        :type: bool
        """
        self._is_customer_deployed = is_customer_deployed

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ManagementAgentSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ManagementAgentSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ManagementAgentSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ManagementAgentSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ManagementAgentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ManagementAgentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ManagementAgentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ManagementAgentSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UploadWarningSummary(object):
    """
    Summary of Upload warnings.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UploadWarningSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param reference:
            The value to assign to the reference property of this UploadWarningSummary.
        :type reference: str

        :param status:
            The value to assign to the status property of this UploadWarningSummary.
        :type status: str

        :param time_started:
            The value to assign to the time_started property of this UploadWarningSummary.
        :type time_started: datetime

        :param error_message:
            The value to assign to the error_message property of this UploadWarningSummary.
        :type error_message: str

        """
        self.swagger_types = {
            'reference': 'str',
            'status': 'str',
            'time_started': 'datetime',
            'error_message': 'str'
        }

        self.attribute_map = {
            'reference': 'reference',
            'status': 'status',
            'time_started': 'timeStarted',
            'error_message': 'errorMessage'
        }

        self._reference = None
        self._status = None
        self._time_started = None
        self._error_message = None

    @property
    def reference(self):
        """
        **[Required]** Gets the reference of this UploadWarningSummary.
        Unique internal identifier to refer upload warning.


        :return: The reference of this UploadWarningSummary.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """
        Sets the reference of this UploadWarningSummary.
        Unique internal identifier to refer upload warning.


        :param reference: The reference of this UploadWarningSummary.
        :type: str
        """
        self._reference = reference

    @property
    def status(self):
        """
        Gets the status of this UploadWarningSummary.
        Status of the upload. Ex - Failed.


        :return: The status of this UploadWarningSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UploadWarningSummary.
        Status of the upload. Ex - Failed.


        :param status: The status of this UploadWarningSummary.
        :type: str
        """
        self._status = status

    @property
    def time_started(self):
        """
        Gets the time_started of this UploadWarningSummary.
        The time when the upload processing started.


        :return: The time_started of this UploadWarningSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this UploadWarningSummary.
        The time when the upload processing started.


        :param time_started: The time_started of this UploadWarningSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def error_message(self):
        """
        Gets the error_message of this UploadWarningSummary.
        The details about upload processing failure.


        :return: The error_message of this UploadWarningSummary.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this UploadWarningSummary.
        The details about upload processing failure.


        :param error_message: The error_message of this UploadWarningSummary.
        :type: str
        """
        self._error_message = error_message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePublicationPackage(object):
    """
    A base object for creating a publication package.
    """

    #: A constant which can be used with the package_type property of a CreatePublicationPackage.
    #: This constant has a value of "ORCHESTRATION"
    PACKAGE_TYPE_ORCHESTRATION = "ORCHESTRATION"

    #: A constant which can be used with the package_type property of a CreatePublicationPackage.
    #: This constant has a value of "IMAGE"
    PACKAGE_TYPE_IMAGE = "IMAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePublicationPackage object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.marketplace.models.CreateImagePublicationPackage`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param package_version:
            The value to assign to the package_version property of this CreatePublicationPackage.
        :type package_version: str

        :param package_type:
            The value to assign to the package_type property of this CreatePublicationPackage.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE"
        :type package_type: str

        :param operating_system:
            The value to assign to the operating_system property of this CreatePublicationPackage.
        :type operating_system: oci.marketplace.models.OperatingSystem

        :param eula:
            The value to assign to the eula property of this CreatePublicationPackage.
        :type eula: list[oci.marketplace.models.Eula]

        """
        self.swagger_types = {
            'package_version': 'str',
            'package_type': 'str',
            'operating_system': 'OperatingSystem',
            'eula': 'list[Eula]'
        }

        self.attribute_map = {
            'package_version': 'packageVersion',
            'package_type': 'packageType',
            'operating_system': 'operatingSystem',
            'eula': 'eula'
        }

        self._package_version = None
        self._package_type = None
        self._operating_system = None
        self._eula = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['packageType']

        if type == 'IMAGE':
            return 'CreateImagePublicationPackage'
        else:
            return 'CreatePublicationPackage'

    @property
    def package_version(self):
        """
        **[Required]** Gets the package_version of this CreatePublicationPackage.
        The package version.


        :return: The package_version of this CreatePublicationPackage.
        :rtype: str
        """
        return self._package_version

    @package_version.setter
    def package_version(self, package_version):
        """
        Sets the package_version of this CreatePublicationPackage.
        The package version.


        :param package_version: The package_version of this CreatePublicationPackage.
        :type: str
        """
        self._package_version = package_version

    @property
    def package_type(self):
        """
        **[Required]** Gets the package_type of this CreatePublicationPackage.
        The package's type.

        Allowed values for this property are: "ORCHESTRATION", "IMAGE"


        :return: The package_type of this CreatePublicationPackage.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this CreatePublicationPackage.
        The package's type.


        :param package_type: The package_type of this CreatePublicationPackage.
        :type: str
        """
        allowed_values = ["ORCHESTRATION", "IMAGE"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            raise ValueError(
                "Invalid value for `package_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._package_type = package_type

    @property
    def operating_system(self):
        """
        **[Required]** Gets the operating_system of this CreatePublicationPackage.

        :return: The operating_system of this CreatePublicationPackage.
        :rtype: oci.marketplace.models.OperatingSystem
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """
        Sets the operating_system of this CreatePublicationPackage.

        :param operating_system: The operating_system of this CreatePublicationPackage.
        :type: oci.marketplace.models.OperatingSystem
        """
        self._operating_system = operating_system

    @property
    def eula(self):
        """
        **[Required]** Gets the eula of this CreatePublicationPackage.
        The end user license agreeement (EULA) that consumers of this listing must accept.


        :return: The eula of this CreatePublicationPackage.
        :rtype: list[oci.marketplace.models.Eula]
        """
        return self._eula

    @eula.setter
    def eula(self, eula):
        """
        Sets the eula of this CreatePublicationPackage.
        The end user license agreeement (EULA) that consumers of this listing must accept.


        :param eula: The eula of this CreatePublicationPackage.
        :type: list[oci.marketplace.models.Eula]
        """
        self._eula = eula

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .mount_type_details import MountTypeDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutomatedMountDetails(MountTypeDetails):
    """
    Used for creating NFS Auto Mount backup destinations for autonomous on ExaCC.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutomatedMountDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.AutomatedMountDetails.mount_type` attribute
        of this class is ``AUTOMATED_MOUNT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param mount_type:
            The value to assign to the mount_type property of this AutomatedMountDetails.
            Allowed values for this property are: "SELF_MOUNT", "AUTOMATED_MOUNT"
        :type mount_type: str

        :param nfs_server:
            The value to assign to the nfs_server property of this AutomatedMountDetails.
        :type nfs_server: list[str]

        :param nfs_server_export:
            The value to assign to the nfs_server_export property of this AutomatedMountDetails.
        :type nfs_server_export: str

        """
        self.swagger_types = {
            'mount_type': 'str',
            'nfs_server': 'list[str]',
            'nfs_server_export': 'str'
        }

        self.attribute_map = {
            'mount_type': 'mountType',
            'nfs_server': 'nfsServer',
            'nfs_server_export': 'nfsServerExport'
        }

        self._mount_type = None
        self._nfs_server = None
        self._nfs_server_export = None
        self._mount_type = 'AUTOMATED_MOUNT'

    @property
    def nfs_server(self):
        """
        **[Required]** Gets the nfs_server of this AutomatedMountDetails.
        IP addresses for NFS Auto mount.


        :return: The nfs_server of this AutomatedMountDetails.
        :rtype: list[str]
        """
        return self._nfs_server

    @nfs_server.setter
    def nfs_server(self, nfs_server):
        """
        Sets the nfs_server of this AutomatedMountDetails.
        IP addresses for NFS Auto mount.


        :param nfs_server: The nfs_server of this AutomatedMountDetails.
        :type: list[str]
        """
        self._nfs_server = nfs_server

    @property
    def nfs_server_export(self):
        """
        **[Required]** Gets the nfs_server_export of this AutomatedMountDetails.
        Specifies the directory on which to mount the file system


        :return: The nfs_server_export of this AutomatedMountDetails.
        :rtype: str
        """
        return self._nfs_server_export

    @nfs_server_export.setter
    def nfs_server_export(self, nfs_server_export):
        """
        Sets the nfs_server_export of this AutomatedMountDetails.
        Specifies the directory on which to mount the file system


        :param nfs_server_export: The nfs_server_export of this AutomatedMountDetails.
        :type: str
        """
        self._nfs_server_export = nfs_server_export

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .available_plugin_summary import AvailablePluginSummary
from .create_instance_agent_command_details import CreateInstanceAgentCommandDetails
from .instance_agent_command import InstanceAgentCommand
from .instance_agent_command_content import InstanceAgentCommandContent
from .instance_agent_command_execution import InstanceAgentCommandExecution
from .instance_agent_command_execution_output_content import InstanceAgentCommandExecutionOutputContent
from .instance_agent_command_execution_output_via_object_storage_tuple_details import InstanceAgentCommandExecutionOutputViaObjectStorageTupleDetails
from .instance_agent_command_execution_output_via_object_storage_uri_details import InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails
from .instance_agent_command_execution_output_via_text_details import InstanceAgentCommandExecutionOutputViaTextDetails
from .instance_agent_command_execution_summary import InstanceAgentCommandExecutionSummary
from .instance_agent_command_output_details import InstanceAgentCommandOutputDetails
from .instance_agent_command_output_via_object_storage_tuple_details import InstanceAgentCommandOutputViaObjectStorageTupleDetails
from .instance_agent_command_output_via_object_storage_uri_details import InstanceAgentCommandOutputViaObjectStorageUriDetails
from .instance_agent_command_output_via_text_details import InstanceAgentCommandOutputViaTextDetails
from .instance_agent_command_source_details import InstanceAgentCommandSourceDetails
from .instance_agent_command_source_via_object_storage_tuple_details import InstanceAgentCommandSourceViaObjectStorageTupleDetails
from .instance_agent_command_source_via_object_storage_uri_details import InstanceAgentCommandSourceViaObjectStorageUriDetails
from .instance_agent_command_source_via_text_details import InstanceAgentCommandSourceViaTextDetails
from .instance_agent_command_summary import InstanceAgentCommandSummary
from .instance_agent_command_target import InstanceAgentCommandTarget
from .instance_agent_plugin import InstanceAgentPlugin
from .instance_agent_plugin_summary import InstanceAgentPluginSummary
from .plugin import Plugin

# Maps type names to classes for compute_instance_agent services.
compute_instance_agent_type_mapping = {
    "AvailablePluginSummary": AvailablePluginSummary,
    "CreateInstanceAgentCommandDetails": CreateInstanceAgentCommandDetails,
    "InstanceAgentCommand": InstanceAgentCommand,
    "InstanceAgentCommandContent": InstanceAgentCommandContent,
    "InstanceAgentCommandExecution": InstanceAgentCommandExecution,
    "InstanceAgentCommandExecutionOutputContent": InstanceAgentCommandExecutionOutputContent,
    "InstanceAgentCommandExecutionOutputViaObjectStorageTupleDetails": InstanceAgentCommandExecutionOutputViaObjectStorageTupleDetails,
    "InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails": InstanceAgentCommandExecutionOutputViaObjectStorageUriDetails,
    "InstanceAgentCommandExecutionOutputViaTextDetails": InstanceAgentCommandExecutionOutputViaTextDetails,
    "InstanceAgentCommandExecutionSummary": InstanceAgentCommandExecutionSummary,
    "InstanceAgentCommandOutputDetails": InstanceAgentCommandOutputDetails,
    "InstanceAgentCommandOutputViaObjectStorageTupleDetails": InstanceAgentCommandOutputViaObjectStorageTupleDetails,
    "InstanceAgentCommandOutputViaObjectStorageUriDetails": InstanceAgentCommandOutputViaObjectStorageUriDetails,
    "InstanceAgentCommandOutputViaTextDetails": InstanceAgentCommandOutputViaTextDetails,
    "InstanceAgentCommandSourceDetails": InstanceAgentCommandSourceDetails,
    "InstanceAgentCommandSourceViaObjectStorageTupleDetails": InstanceAgentCommandSourceViaObjectStorageTupleDetails,
    "InstanceAgentCommandSourceViaObjectStorageUriDetails": InstanceAgentCommandSourceViaObjectStorageUriDetails,
    "InstanceAgentCommandSourceViaTextDetails": InstanceAgentCommandSourceViaTextDetails,
    "InstanceAgentCommandSummary": InstanceAgentCommandSummary,
    "InstanceAgentCommandTarget": InstanceAgentCommandTarget,
    "InstanceAgentPlugin": InstanceAgentPlugin,
    "InstanceAgentPluginSummary": InstanceAgentPluginSummary,
    "Plugin": Plugin
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_read_attribute import AbstractReadAttribute
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OracleReadAttributes(AbstractReadAttribute):
    """
    Properties to configure reading from an Oracle Database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OracleReadAttributes object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.OracleReadAttributes.model_type` attribute
        of this class is ``ORACLE_READ_ATTRIBUTE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this OracleReadAttributes.
            Allowed values for this property are: "ORACLEREADATTRIBUTE", "ORACLE_READ_ATTRIBUTE", "BICC_READ_ATTRIBUTE"
        :type model_type: str

        :param fetch_size:
            The value to assign to the fetch_size property of this OracleReadAttributes.
        :type fetch_size: int

        """
        self.swagger_types = {
            'model_type': 'str',
            'fetch_size': 'int'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'fetch_size': 'fetchSize'
        }

        self._model_type = None
        self._fetch_size = None
        self._model_type = 'ORACLE_READ_ATTRIBUTE'

    @property
    def fetch_size(self):
        """
        Gets the fetch_size of this OracleReadAttributes.
        The fetch size for reading.


        :return: The fetch_size of this OracleReadAttributes.
        :rtype: int
        """
        return self._fetch_size

    @fetch_size.setter
    def fetch_size(self, fetch_size):
        """
        Sets the fetch_size of this OracleReadAttributes.
        The fetch size for reading.


        :param fetch_size: The fetch_size of this OracleReadAttributes.
        :type: int
        """
        self._fetch_size = fetch_size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
